@@ -1,21 +1,19 @@
-/***************************************************************************
- *   Copyright (C) 2008,2011 by Volker Lanz <vl@fidra.de>                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*************************************************************************
+ *  Copyright (C) 2008, 2011 by Volker Lanz <vl@fidra.de>                *
+ *                                                                       *
+ *  This program is free software; you can redistribute it and/or        *
+ *  modify it under the terms of the GNU General Public License as       *
+ *  published by the Free Software Foundation; either version 3 of       *
+ *  the License, or (at your option) any later version.                  *
+ *                                                                       *
+ *  This program is distributed in the hope that it will be useful,      *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
+ *  GNU General Public License for more details.                         *
+ *                                                                       *
+ *  You should have received a copy of the GNU General Public License    *
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
+ *************************************************************************/
 
 #include "core/operationstack.h"
 #include "core/device.h"
@@ -40,8 +38,7 @@
 
 #include "util/globallog.h"
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include <QReadLocker>
 #include <QWriteLocker>
@@ -105,7 +102,7 @@ bool OperationStack::mergeNewOperation(Operation*& currentOp, Operation*& pushed
 	SetFileSystemLabelOperation* pushedLabelOp = dynamic_cast<SetFileSystemLabelOperation*>(pushedOp);
 	CreateFileSystemOperation* pushedCreateFileSystemOp = dynamic_cast<CreateFileSystemOperation*>(pushedOp);
 	CheckOperation* pushedCheckOp = dynamic_cast<CheckOperation*>(pushedOp);
-	
+
 	// -- 1 --
 	if (pushedDeleteOp && &newOp->newPartition() == &pushedDeleteOp->deletedPartition() && !pushedDeleteOp->deletedPartition().roles().has(PartitionRole::Extended))
 	{
@@ -200,13 +197,13 @@ bool OperationStack::mergeNewOperation(Operation*& currentOp, Operation*& pushed
 	if (pushedCheckOp && &newOp->newPartition() == &pushedCheckOp->checkedPartition())
 	{
 		Log() << i18nc("@info/plain", "Checking file systems is automatically done when creating them: No new operation required.");
-		
+
 		delete pushedOp;
 		pushedOp = NULL;
-		
+
 		return true;
 	}
-	
+
 	return false;
 }
 
